@@ -127,6 +127,68 @@ subroutine ust_horizon( cmd, va, velst )
 
 end subroutine
 
+!--------------------------------------------------------
+!--------------------------------------------------------
+
+subroutine Brunt_Freq( nx, ny, nz, dx, dy, dz, pt, BV, undeff )
+! ֥ȥХ鿶ư׻
+  use analy
+  use Phys_Const
+  implicit none
+  integer, intent(in) :: nx  !  1 ǿ
+  integer, intent(in) :: ny  !  2 ǿ
+  integer, intent(in) :: nz  !  3 ǿ
+  real, intent(in) :: dx  ! x γʻҴֳ [m]
+  real, intent(in) :: dy  ! y γʻҴֳ [m]
+  real, intent(in) :: dz  ! z γʻҴֳ [m]
+  real, intent(in) :: pt(nx,ny,nz)  !  [K]
+  real, intent(inout) :: BV(nx,ny,nz)  ! ֥ȥХ鿶ư [1/s]
+  real, intent(in), optional :: undeff
+  integer :: i, j, k
+
+  if(present(undeff))then
+!$omp parallel default(shared)
+!$omp do private(i,j)
+     do j=1,ny
+        do i=1,nx
+           call grad_1d( nz, dz, pt(i,j,:), BV(i,j,:), undeff )
+        end do
+     end do
+!$omp end do
+!$omp end parallel
+
+  else
+
+!$omp parallel default(shared)
+!$omp do private(i,j)
+     do j=1,ny
+        do i=1,nx
+           call grad_1d( nz, dz, pt(i,j,:), BV(i,j,:) )
+        end do
+     end do
+!$omp end do
+!$omp end parallel
+  end if
+
+  do k=1,nz
+     do j=1,ny
+        do i=1,nx
+           if(present(undeff))then
+              if(BV(i,j,k)==undeff)then
+                 BV(i,j,k)=undeff
+              else
+                 BV(i,j,k)=(g/pt(i,j,k))*BV(i,j,k)
+              end if
+           else
+              BV(i,j,k)=(g/pt(i,j,k))*BV(i,j,k)
+           end if
+        end do
+     end do
+  end do
+
+end subroutine
+
+!--------------------------------------------------------
 !--------------------------------------------------------
 
 subroutine Ertel_PV( nx, ny, nz, dx, dy, dz, u, v, w, rho, pt, pv, undeff )
