@@ -584,6 +584,64 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
+real function qrsg_2_dbz( rho, qr, qs, qg )
+! 庮椫鵼Ūʥ졼ȿͶ٤Ѵؿ.
+! 졼ȿͶ dbz ϥ졼ȿͰ Z Ѥ,
+! $$ dbz = 10 \log{Z} $$
+! . , ȿͰ Z 
+! $$Z=\sum_{D^6} =int^{\infty}_{0}{N(D)D^6dD} $$
+! Ȥ. , D Ͽʪľ, N Ͽ̩٤Ǥ.
+! Ǥϵݥ졼ꤷƤΤ, ߿γҤΥƥ
+! , ,  ΤߤȤ.
+! warm rain ξǤ, Ǥκ򥼥ǰ뤳ȤǷ׻ǽ.
+! γʬۤϻؿؿʬۤꤷƷ׻. ξ, ƥƥγҤγʬۤ
+! γҤľ¤ D_x Ȥ, 
+! $$n_x(D_x)=n_{x0}\exp{(-\lambda _xD_x)} $$
+! Ȥɽ. , $\lambda _x$γʬۤηǤ.
+! ѴȤƤ, Murakami (1990)  (54) ѤƷ׻Ԥ.
+  use Math_Const
+  use Special_Function
+  implicit none
+  real, intent(in) :: rho  ! 絤̩ [kg/m^3]
+  real, intent(in) :: qr  ! κ [kg/kg]
+  real, intent(in), optional :: qs  ! κ [kg/kg]
+  real, intent(in), optional :: qg  ! Ǥκ [kg/kg]
+  real, parameter :: nr0=8.0e6  !  y ǻ [1/m^4]
+  real, parameter :: ns0=1.8e6  !  y ǻ [1/m^4]
+  real, parameter :: ng0=1.1e6  ! Ǥ y ǻ [1/m^4]
+                                ! y ǻ٤ CReSS ͤѤ.
+  real, parameter :: rhos=84.0  ! ̩ [kg/m^3]
+  real, parameter :: rhog=300.0  ! Ǥ̩ [kg/m^3]
+                                ! ǤϷ뾽¤ư뤬, Ǥϰͤ
+                                ! ꤷ, CReSS ͤѤ.
+  real, parameter :: epi=4.2  ! ɹͶΨ
+  real, parameter :: epw=80.0 ! ͶΨ
+  real :: coef
+  real :: z_tmp
+
+  z_tmp=0.0
+  coef=kaijo(6.0)*(((epi-1.0)/(epi+2.0))/((epw-1.0)/(epw+2.0))**2)
+
+  if(present(qs))then
+     z_tmp=z_tmp+coef*((rhos/rhow)**2)*ns0*((rho*qs/(pi*rhos*ns0))**1.75)*1.0e18
+  end if
+
+  if(present(qg))then
+     z_tmp=z_tmp+coef*((rhog/rhow)**2)*ng0*((rho*qg/(pi*rhog*ng0))**1.75)*1.0e18
+  end if
+
+  z_tmp=z_tmp+nr0*((rho*qr/(pi*rhow*nr0))**1.75)*1.0e18
+  z_tmp=coef*z_tmp
+
+  if(z_tmp>0.0)then
+     qrsg_2_dbz=10.0*log10(z_tmp)
+  else
+     qrsg_2_dbz=0.0
+  end if
+
+  return
+end function
+
 !-----------------------------------------------------
 !-----------------------------------------------------
 
